@@ -29,12 +29,13 @@ class TestDocument(unittest.TestCase):
                 "plone.basic",
                 "plone.locking",
                 "volto.blocks",
+                "plone.translatable",
             ),
         )
 
     def test_event_addable_types(self):
         portal_types = api.portal.get_tool(name="portal_types")
         self.assertEqual(
-            ("Document", "Documento", "Link"),
+            ("Document", "Documento", "Link", "Image"),
             portal_types["CartellaModulistica"].allowed_content_types,
         )
